@@ -1,7 +1,12 @@
 extern crate alloc;
+use alloc::borrow::ToOwned;
 
 pub trait Storage {
-    type Error;
+    #[cfg(not(feature = "std"))]
+    type Error: core::fmt::Debug + core::fmt::Display;
+
+    #[cfg(feature = "std")]
+    type Error: std::error::Error + Send + Sync + 'static;
 
     fn contains(&self, key: impl AsRef<str>) -> Result<bool, Self::Error>;
 
@@ -39,57 +44,6 @@ pub trait Storage {
     }
 }
 
-pub struct AnyhowStorage<T>(pub T);
-
-impl<E, S> Storage for AnyhowStorage<S>
-where
-    E: Into<anyhow::Error>,
-    S: Storage<Error = E>,
-{
-    type Error = anyhow::Error;
-
-    fn contains(&self, key: impl AsRef<str>) -> Result<bool, Self::Error> {
-        self.0.contains(key).map_err(Into::into)
-    }
-
-    fn remove(&mut self, key: impl AsRef<str>) -> Result<bool, Self::Error> {
-        self.0.remove(key).map_err(Into::into)
-    }
-
-    fn len(&self, key: impl AsRef<str>) -> Result<Option<usize>, Self::Error> {
-        self.0.len(key).map_err(Into::into)
-    }
-
-    fn get_raw(&self, key: impl AsRef<str>) -> Result<Option<alloc::vec::Vec<u8>>, Self::Error> {
-        self.0.get_raw(key).map_err(Into::into)
-    }
-
-    fn put_raw(
-        &mut self,
-        key: impl AsRef<str>,
-        value: impl Into<alloc::vec::Vec<u8>>,
-    ) -> Result<bool, Self::Error> {
-        self.0.put_raw(key, value).map_err(Into::into)
-    }
-
-    #[cfg(feature = "use_serde")]
-    fn get<T: serde::de::DeserializeOwned>(
-        &self,
-        key: impl AsRef<str>,
-    ) -> Result<Option<T>, Self::Error> {
-        self.0.get(key).map_err(Into::into)
-    }
-
-    #[cfg(feature = "use_serde")]
-    fn put(
-        &mut self,
-        key: impl AsRef<str>,
-        value: &impl serde::Serialize,
-    ) -> Result<bool, Self::Error> {
-        self.0.put(key, value).map_err(Into::into)
-    }
-}
-
 pub struct MemoryStorage(alloc::collections::BTreeMap<alloc::string::String, alloc::vec::Vec<u8>>);
 
 impl MemoryStorage {
